@@ -3,9 +3,7 @@
 -- -----------------------------------------------------------------------
 
 
-drop table ID_TABLE;
-
-
+drop table ID_TABLE if exists;
 
 -- -----------------------------------------------------------------------
 -- ID_TABLE
@@ -17,11 +15,7 @@ CREATE TABLE ID_TABLE
     NEXT_ID INTEGER,
     QUANTITY INTEGER,
     PRIMARY KEY(ID_TABLE_ID),
-    CONSTRAINT ID_TABLE_UQ_1 UNIQUE(TABLE_NAME));
-
-
-
-
-
+    CONSTRAINT ID_TABLE_UQ_1 UNIQUE(TABLE_NAME)
+);
 
 
